@@ -9,7 +9,7 @@ print.dma <- function(x, ...)
    cat("\n")
    print(x$parameters)
    cat("\n")
-   err <- rbind(x$MSE,x$MAE)
+   err <- rbind(x$RMSE,x$MAE)
    colnames(err) <- c("model")
    err <- cbind(err,x$benchmarks)
    print(round(err,digits=4))
